==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d8/ddc/industry__gui_8cpp.js <==
var industry__gui_8cpp =
[
    [ "CargoSuffix", "dd/d12/structCargoSuffix.html", "dd/d12/structCargoSuffix" ],
    [ "BuildIndustryWindow", "dc/d08/classBuildIndustryWindow.html", "dc/d08/classBuildIndustryWindow" ],
    [ "IndustryViewWindow", "d5/d13/classIndustryViewWindow.html", "d5/d13/classIndustryViewWindow" ],
    [ "IndustryDirectoryWindow", "d3/de3/classIndustryDirectoryWindow.html", "d3/de3/classIndustryDirectoryWindow" ],
    [ "CargoesField", "d6/d10/structCargoesField.html", "d6/d10/structCargoesField" ],
    [ "CargoesRow", "d8/dc7/structCargoesRow.html", "d8/dc7/structCargoesRow" ],
    [ "IndustryCargoesWindow", "d3/d96/structIndustryCargoesWindow.html", "d3/d96/structIndustryCargoesWindow" ],
    [ "GUIIndustryList", "d8/ddc/industry__gui_8cpp.html#a134693b08738712a819c0d1d19c5546d", null ],
    [ "CargoesFieldType", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6", [
      [ "CFT_EMPTY", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6a26bf459aeaee9717b72c5681968be796", null ],
      [ "CFT_SMALL_EMPTY", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6a187deffc958e7f993f5934e7f3816cf7", null ],
      [ "CFT_INDUSTRY", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6a81c79430dcbbfb7e09607367ff0c0f68", null ],
      [ "CFT_CARGO", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6a87f5c070a855705c25f3b673935ce499", null ],
      [ "CFT_CARGO_LABEL", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6adcd3038bbbeb8c7a46d40427c722d92a", null ],
      [ "CFT_HEADER", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6acd728415f24b5d63cc4e732e9d24ad32", null ]
    ] ],
    [ "CargoSuffixDisplay", "d8/ddc/industry__gui_8cpp.html#adeb9d5a9e21b6b84ee2ca6574956a980", [
      [ "CSD_CARGO", "d8/ddc/industry__gui_8cpp.html#adeb9d5a9e21b6b84ee2ca6574956a980a19697f51969b25a091e516d2ea49cb31", null ],
      [ "CSD_CARGO_AMOUNT", "d8/ddc/industry__gui_8cpp.html#adeb9d5a9e21b6b84ee2ca6574956a980ac15fae66ff7128777ec8151bd6ed520d", null ],
      [ "CSD_CARGO_TEXT", "d8/ddc/industry__gui_8cpp.html#adeb9d5a9e21b6b84ee2ca6574956a980a16fe9082459993df85adc1ec025eaabf", null ],
      [ "CSD_CARGO_AMOUNT_TEXT", "d8/ddc/industry__gui_8cpp.html#adeb9d5a9e21b6b84ee2ca6574956a980a1bf7376baef02253ec00818abc1699c9", null ]
    ] ],
    [ "CargoSuffixInOut", "d8/ddc/industry__gui_8cpp.html#a4366bc97fbd0cb68fbaf2e2c54759d02", [
      [ "CARGOSUFFIX_OUT", "d8/ddc/industry__gui_8cpp.html#a4366bc97fbd0cb68fbaf2e2c54759d02aa5c7c6aa8787e4fce5ae63c5fc4ccb87", null ],
      [ "CARGOSUFFIX_IN", "d8/ddc/industry__gui_8cpp.html#a4366bc97fbd0cb68fbaf2e2c54759d02a2975edcd7380e17e9892a21f9ec2c276", null ]
    ] ],
    [ "CargoSuffixType", "d8/ddc/industry__gui_8cpp.html#a56a74b9593ba52abe055bafed8b451bb", [
      [ "CST_FUND", "d8/ddc/industry__gui_8cpp.html#a56a74b9593ba52abe055bafed8b451bba8b1beb9aa8ec7f7156ad8451f3e34069", null ],
      [ "CST_VIEW", "d8/ddc/industry__gui_8cpp.html#a56a74b9593ba52abe055bafed8b451bbad1cb41dfb4afeb2ba26375b34cef3399", null ],
      [ "CST_DIR", "d8/ddc/industry__gui_8cpp.html#a56a74b9593ba52abe055bafed8b451bba7f5626bd38f6bf28103e4e2715fc0a53", null ]
    ] ],
    [ "assert_compile", "d8/ddc/industry__gui_8cpp.html#a92d42fae367a160fdfb6b0371d3bccd0", null ],
    [ "assert_compile", "d8/ddc/industry__gui_8cpp.html#afc11f194cff110d1abb9c67ba989bf15", null ],
    [ "CcBuildIndustry", "d8/ddc/industry__gui_8cpp.html#aa7cb3ec858faa0410d3cfb58764b2de4", null ],
    [ "GetAllCargoSuffixes", "d8/ddc/industry__gui_8cpp.html#a3f8c0eaf6d60899d1c5b4f1928d71b93", null ],
    [ "GetCargoSuffix", "d8/ddc/industry__gui_8cpp.html#a1642197d6f53b6058bd72fb2facd4e7c", null ],
    [ "IndustryTypeNameSorter", "d8/ddc/industry__gui_8cpp.html#ae559bad2625095db01698c5af07fab21", null ],
    [ "IsProductionAlterable", "d8/ddc/industry__gui_8cpp.html#ac21194d0480b48e55df37dd1476e4a09", null ],
    [ "ShowBuildIndustryWindow", "d8/ddc/industry__gui_8cpp.html#ad04875507288b140b2849dc90040fd8b", null ],
    [ "ShowIndustryCargoesWindow", "d8/ddc/industry__gui_8cpp.html#acdcc2bf66301665a8832189d3592f134", null ],
    [ "ShowIndustryCargoesWindow", "d8/ddc/industry__gui_8cpp.html#a0acb8f259cf3dcb8f84fbef9f3f5ecd7", null ],
    [ "ShowIndustryDirectory", "d8/ddc/industry__gui_8cpp.html#aa751757e3348c38f33ea8aa648ca4c62", null ],
    [ "ShowIndustryViewWindow", "d8/ddc/industry__gui_8cpp.html#a483598804ce6be766aa106cb29d2e210", null ],
    [ "SortIndustryTypes", "d8/ddc/industry__gui_8cpp.html#af8e88d4cf3f2021b94c3b4ffaf47d58d", null ],
    [ "UpdateIndustryProduction", "d8/ddc/industry__gui_8cpp.html#a760891cbcabbf2a5f32cc837193fb383", null ],
    [ "_build_industry_desc", "d8/ddc/industry__gui_8cpp.html#ad159fe877ed66b316664cadc16704304", null ],
    [ "_displayed_industries", "d8/ddc/industry__gui_8cpp.html#ab409c58c2a945d396bde9624a42bfcae", null ],
    [ "_ignore_restrictions", "d8/ddc/industry__gui_8cpp.html#aa43b5e21ec68f5548cdf08a303e7fabc", null ],
    [ "_industry_cargoes_desc", "d8/ddc/industry__gui_8cpp.html#a904824bbd8cae591b9387d74e016c480", null ],
    [ "_industry_directory_desc", "d8/ddc/industry__gui_8cpp.html#ae51de665fe3f3e4237022cdc0cb3fbec", null ],
    [ "_industry_view_desc", "d8/ddc/industry__gui_8cpp.html#a1a250d84cce4618ad75c48c17f916bd4", null ],
    [ "_nested_build_industry_widgets", "d8/ddc/industry__gui_8cpp.html#ad488455f4bb49ca32ef1c1ecee860735", null ],
    [ "_nested_industry_cargoes_widgets", "d8/ddc/industry__gui_8cpp.html#a37ad95b36f0d0989ed7ff2690b29de8a", null ],
    [ "_nested_industry_directory_widgets", "d8/ddc/industry__gui_8cpp.html#a0bc8afe4cfd57a9b5c047dd09d49bb03", null ],
    [ "_nested_industry_view_widgets", "d8/ddc/industry__gui_8cpp.html#a64ed9ba8f63de42c7f0d72e2623ee5c4", null ],
    [ "_sorted_industry_types", "d8/ddc/industry__gui_8cpp.html#a3e15c4bfdb0b87c21f4487f603c3e5a0", null ],
    [ "MAX_CARGOES", "d8/ddc/industry__gui_8cpp.html#a2145855a848bcebd4a61b7ef6f9d816b", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d8/ddc/industry__gui_8cpp.js <==
var industry__gui_8cpp =
[
    [ "CargoSuffix", "dd/d12/structCargoSuffix.html", "dd/d12/structCargoSuffix" ],
    [ "BuildIndustryWindow", "dc/d08/classBuildIndustryWindow.html", "dc/d08/classBuildIndustryWindow" ],
    [ "IndustryViewWindow", "d5/d13/classIndustryViewWindow.html", "d5/d13/classIndustryViewWindow" ],
    [ "IndustryDirectoryWindow", "d3/de3/classIndustryDirectoryWindow.html", "d3/de3/classIndustryDirectoryWindow" ],
    [ "CargoesField", "d6/d10/structCargoesField.html", "d6/d10/structCargoesField" ],
    [ "CargoesRow", "d8/dc7/structCargoesRow.html", "d8/dc7/structCargoesRow" ],
    [ "IndustryCargoesWindow", "d3/d96/structIndustryCargoesWindow.html", "d3/d96/structIndustryCargoesWindow" ],
    [ "GUIIndustryList", "d8/ddc/industry__gui_8cpp.html#a36decba3510e13fcf49de76b0bdba48e", null ],
    [ "CargoesFieldType", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6", [
      [ "CFT_EMPTY", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6a26bf459aeaee9717b72c5681968be796", null ],
      [ "CFT_SMALL_EMPTY", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6a187deffc958e7f993f5934e7f3816cf7", null ],
      [ "CFT_INDUSTRY", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6a81c79430dcbbfb7e09607367ff0c0f68", null ],
      [ "CFT_CARGO", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6a87f5c070a855705c25f3b673935ce499", null ],
      [ "CFT_CARGO_LABEL", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6adcd3038bbbeb8c7a46d40427c722d92a", null ],
      [ "CFT_HEADER", "d8/ddc/industry__gui_8cpp.html#a24bffbbbb2847a14eb590dea38ed00c6acd728415f24b5d63cc4e732e9d24ad32", null ]
    ] ],
    [ "CargoFilterSpecialType", "d8/ddc/industry__gui_8cpp.html#acf3639a6931e5860d5880263dd12381f", [
      [ "CF_ANY", "d8/ddc/industry__gui_8cpp.html#acf3639a6931e5860d5880263dd12381fa451083f1199b608eb59782d605e5197f", null ],
      [ "CF_NONE", "d8/ddc/industry__gui_8cpp.html#acf3639a6931e5860d5880263dd12381fab5fbdef2ff2606428375c68b7b303652", null ]
    ] ],
    [ "CargoSuffixDisplay", "d8/ddc/industry__gui_8cpp.html#adeb9d5a9e21b6b84ee2ca6574956a980", [
      [ "CSD_CARGO", "d8/ddc/industry__gui_8cpp.html#adeb9d5a9e21b6b84ee2ca6574956a980a19697f51969b25a091e516d2ea49cb31", null ],
      [ "CSD_CARGO_AMOUNT", "d8/ddc/industry__gui_8cpp.html#adeb9d5a9e21b6b84ee2ca6574956a980ac15fae66ff7128777ec8151bd6ed520d", null ],
      [ "CSD_CARGO_TEXT", "d8/ddc/industry__gui_8cpp.html#adeb9d5a9e21b6b84ee2ca6574956a980a16fe9082459993df85adc1ec025eaabf", null ],
      [ "CSD_CARGO_AMOUNT_TEXT", "d8/ddc/industry__gui_8cpp.html#adeb9d5a9e21b6b84ee2ca6574956a980a1bf7376baef02253ec00818abc1699c9", null ]
    ] ],
    [ "CargoSuffixInOut", "d8/ddc/industry__gui_8cpp.html#a4366bc97fbd0cb68fbaf2e2c54759d02", [
      [ "CARGOSUFFIX_OUT", "d8/ddc/industry__gui_8cpp.html#a4366bc97fbd0cb68fbaf2e2c54759d02aa5c7c6aa8787e4fce5ae63c5fc4ccb87", null ],
      [ "CARGOSUFFIX_IN", "d8/ddc/industry__gui_8cpp.html#a4366bc97fbd0cb68fbaf2e2c54759d02a2975edcd7380e17e9892a21f9ec2c276", null ]
    ] ],
    [ "CargoSuffixType", "d8/ddc/industry__gui_8cpp.html#a56a74b9593ba52abe055bafed8b451bb", [
      [ "CST_FUND", "d8/ddc/industry__gui_8cpp.html#a56a74b9593ba52abe055bafed8b451bba8b1beb9aa8ec7f7156ad8451f3e34069", null ],
      [ "CST_VIEW", "d8/ddc/industry__gui_8cpp.html#a56a74b9593ba52abe055bafed8b451bbad1cb41dfb4afeb2ba26375b34cef3399", null ],
      [ "CST_DIR", "d8/ddc/industry__gui_8cpp.html#a56a74b9593ba52abe055bafed8b451bba7f5626bd38f6bf28103e4e2715fc0a53", null ]
    ] ],
    [ "CargoFilter", "d8/ddc/industry__gui_8cpp.html#a6d5128c9e0700e79615aa02757a0d007", null ],
    [ "CcBuildIndustry", "d8/ddc/industry__gui_8cpp.html#a07da73be191b0aed1a659499eeff15f6", null ],
    [ "GetAllCargoSuffixes", "d8/ddc/industry__gui_8cpp.html#a3f8c0eaf6d60899d1c5b4f1928d71b93", null ],
    [ "GetCargoSuffix", "d8/ddc/industry__gui_8cpp.html#a1642197d6f53b6058bd72fb2facd4e7c", null ],
    [ "IndustryTypeNameSorter", "d8/ddc/industry__gui_8cpp.html#a7dca9da072b66b491793aa0022c4b65a", null ],
    [ "IsProductionAlterable", "d8/ddc/industry__gui_8cpp.html#ac21194d0480b48e55df37dd1476e4a09", null ],
    [ "ShowBuildIndustryWindow", "d8/ddc/industry__gui_8cpp.html#ad04875507288b140b2849dc90040fd8b", null ],
    [ "ShowIndustryCargoesWindow", "d8/ddc/industry__gui_8cpp.html#a0acb8f259cf3dcb8f84fbef9f3f5ecd7", null ],
    [ "ShowIndustryCargoesWindow", "d8/ddc/industry__gui_8cpp.html#acdcc2bf66301665a8832189d3592f134", null ],
    [ "ShowIndustryDirectory", "d8/ddc/industry__gui_8cpp.html#aa751757e3348c38f33ea8aa648ca4c62", null ],
    [ "ShowIndustryViewWindow", "d8/ddc/industry__gui_8cpp.html#a483598804ce6be766aa106cb29d2e210", null ],
    [ "SortIndustryTypes", "d8/ddc/industry__gui_8cpp.html#af8e88d4cf3f2021b94c3b4ffaf47d58d", null ],
    [ "UpdateIndustryProduction", "d8/ddc/industry__gui_8cpp.html#a760891cbcabbf2a5f32cc837193fb383", null ],
    [ "_build_industry_desc", "d8/ddc/industry__gui_8cpp.html#ad159fe877ed66b316664cadc16704304", null ],
    [ "_displayed_industries", "d8/ddc/industry__gui_8cpp.html#ab409c58c2a945d396bde9624a42bfcae", null ],
    [ "_filter_funcs", "d8/ddc/industry__gui_8cpp.html#a4bcffaf160a58bf45fc802e1edce9a5a", null ],
    [ "_ignore_restrictions", "d8/ddc/industry__gui_8cpp.html#aa43b5e21ec68f5548cdf08a303e7fabc", null ],
    [ "_industry_cargoes_desc", "d8/ddc/industry__gui_8cpp.html#a904824bbd8cae591b9387d74e016c480", null ],
    [ "_industry_directory_desc", "d8/ddc/industry__gui_8cpp.html#ae51de665fe3f3e4237022cdc0cb3fbec", null ],
    [ "_industry_view_desc", "d8/ddc/industry__gui_8cpp.html#a1a250d84cce4618ad75c48c17f916bd4", null ],
    [ "_nested_build_industry_widgets", "d8/ddc/industry__gui_8cpp.html#ad488455f4bb49ca32ef1c1ecee860735", null ],
    [ "_nested_industry_cargoes_widgets", "d8/ddc/industry__gui_8cpp.html#a37ad95b36f0d0989ed7ff2690b29de8a", null ],
    [ "_nested_industry_directory_widgets", "d8/ddc/industry__gui_8cpp.html#a0bc8afe4cfd57a9b5c047dd09d49bb03", null ],
    [ "_nested_industry_view_widgets", "d8/ddc/industry__gui_8cpp.html#a64ed9ba8f63de42c7f0d72e2623ee5c4", null ],
    [ "_sorted_industry_types", "d8/ddc/industry__gui_8cpp.html#a97d2018ed36e3d81c61eb4b5db9aed4f", null ],
    [ "MAX_CARGOES", "d8/ddc/industry__gui_8cpp.html#a2145855a848bcebd4a61b7ef6f9d816b", null ]
];
